================================
``psyclone.psyir.nodes.literal``
================================

.. automodule:: psyclone.psyir.nodes.literal

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.literal
